==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/es.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Sus ajustes han sido actualizados.",
"Activity" => "Actividad",
"A file or folder has been <strong>shared</strong>" => "Se ha <strong>compartido</strong> un archivo o carpeta",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Un nuevo archivo o carpeta ha sido <strong>creado/a</strong> en una carpeta compartida",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Un archivo o carpeta ha sido <strong>modificado/a</strong> en una carpeta compartida",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Un archivo o carpeta ha sido <strong>eliminado/a</strong> de una carpeta compartida",
"You created %1\$s" => "Usted ha creado %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creado %1\$s",
"You changed %1\$s" => "Usted ha modificado %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha modificado %1\$s",
"You deleted %1\$s" => "Usted ha eliminado %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha eliminado %1\$s",
"You shared %1\$s with %2\$s" => "Usted ha compartido %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Usted ha compartido %1\$s con el grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha compartido %1\$s con usted",
"You shared %1\$s via link" => "Ha compartido %1\$s via enlace",
"Activity notification" => "Notificación de actividad",
"All Activities" => "Todas las actividades",
"Activities by you" => "Tus actividades",
"Activities by others" => "Actividades de otros",
"Shares" => "Compartidos",
"Files" => "Archivos",
"%s and %s" => "%s y %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>","%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s y %n más","%s y %n más"),
"Hello %s," => "Estimado/a %s:",
"You are receiving this email because in the last hour the following things happened at %s" => "Está recibiendo este mensaje porque durante la última hora han pasado las siguientes cosas en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Está recibiendo este mensaje porque durante la última semana han pasado las siguientes cosas en %s ",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Aquí aparecerá una lista de eventos cuando comience a usar su %s.",
"No more events to load" => "No hay más eventos por cargar.",
"Enable RSS feed" => "Habilitar fuente RSS",
"Notifications" => "Notificaciones",
"Mail" => "Correo electrónico",
"Stream" => "Flujo",
"You need to set up your email address before you can receive notification emails." => "Debe configurar su dirección de correo electrónico antes de poder recibir notificaciones.",
"Send emails:" => "Enviar mensajes:",
"Hourly" => "Cada hora",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Activity feed" => "Alimentador de actividad",
"Personal activity feed for %s" => "Alimentador de actividad personal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/es.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Sus ajustes han sido actualizados.",
"Activity" => "Actividad",
"A file or folder has been <strong>shared</strong>" => "Se ha <strong>compartido</strong> un archivo o carpeta",
"A new file or folder has been <strong>created</strong>" => "Ha sido <strong>creado</strong> un nuevo archivo o carpeta",
"A file or folder has been <strong>changed</strong>" => "Ha sido <strong>modificado</strong> un archivo o carpeta",
"A file or folder has been <strong>deleted</strong>" => "Ha sido <strong>eliminado</strong> un archivo o carpeta",
"You created %1\$s" => "Usted ha creado %1\$s",
"%2\$s created %1\$s" => "%2\$s ha creado %1\$s",
"You changed %1\$s" => "Usted ha modificado %1\$s",
"%2\$s changed %1\$s" => "%2\$s ha modificado %1\$s",
"You deleted %1\$s" => "Usted ha eliminado %1\$s",
"%2\$s deleted %1\$s" => "%2\$s ha eliminado %1\$s",
"You shared %1\$s with %2\$s" => "Usted ha compartido %1\$s con %2\$s",
"You shared %1\$s with group %2\$s" => "Usted ha compartido %1\$s con el grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s ha compartido %1\$s con usted",
"You shared %1\$s via link" => "Ha compartido %1\$s via enlace",
"Activity notification" => "Notificación de actividad",
"All Activities" => "Todas las actividades",
"Activities by you" => "Tus actividades",
"Activities by others" => "Actividades de otros",
"Shares" => "Compartidos",
"Files" => "Archivos",
"%s and %s" => "%s y %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>","%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s y %n más","%s y %n más"),
"Hello %s," => "Estimado/a %s:",
"You are receiving this email because in the last hour the following things happened at %s" => "Está recibiendo este mensaje porque durante la última hora han pasado las siguientes cosas en %s",
"You are receiving this email because in the last day the following things happened at %s" => "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
"You are receiving this email because in the last week the following things happened at %s" => "Está recibiendo este mensaje porque durante la última semana han pasado las siguientes cosas en %s ",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Aquí aparecerá una lista de eventos cuando comience a usar su %s.",
"No more events to load" => "No hay más eventos por cargar.",
"Enable RSS feed" => "Habilitar fuente RSS",
"Notifications" => "Notificaciones",
"Mail" => "Correo electrónico",
"Stream" => "Flujo",
"Notify about my own actions" => "Notificarme mis propias acciones",
"You need to set up your email address before you can receive notification emails." => "Debe configurar su dirección de correo electrónico antes de poder recibir notificaciones.",
"Send emails:" => "Enviar mensajes:",
"Hourly" => "Cada hora",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Activity feed" => "Alimentador de actividad",
"Personal activity feed for %s" => "Alimentador de actividad personal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
